A Pelican Blog - bar

# Deuxième article

Ceci est un article, en français.

# Other articles

1. # Second article

   This is some article, in english

   read more

2. # This is a super article !

   Multi-line metadata should be supported as well as inline markup.

   read more

3. # Oh yeah !

   ## Why not ?

   After all, why not ? It's pretty simple to do it, and it will allow me to write my blogposts in rst ! YEAH !

   read more